<?php
/**
 * Update-script for blog-module.
 *
 * @author Thomas Kaelin <thomas.kaelin@comvation.com>
 */
define ('DB_ENGINE', 'MYISAM');
define ('NETWORK_IMAGE_PATH', 'images/blog/networks/');

$strQuery = '';

function _blogUpdate() {
	if (!createSettingsTable()) { return handleError(); }
	if (!fillSettingsTable()) { return handleError(); }

	if (!createEntryTable()) { return handleError(); }
	if (!fillEntryTable()) { return handleError(); }

	if (!createEntryTranslationTable()) { return handleError(); }
	if (!fillEntryTranslationTable()) { return handleError(); }

	if (!createCategoryTable()) { return handleError(); }
	if (!fillCategoryTable()) { return handleError(); }

	if (!createCategoryAssignmentTable()) { return handleError(); }
	if (!fillCategoryAssignmentTable()) { return handleError(); }

	if (!createVotingTable()) { return handleError(); }
	if (!fillVotingTable()) { return handleError(); }

	if (!createCommentTable()) { return handleError(); }
	if (!fillCommentTable()) { return handleError(); }

	if (!createNetworkTable()) { return handleError(); }
	if (!fillNetworkTable()) { return handleError(); }

	if (!createNetworkAssignmentTable()) { return handleError(); }
	if (!fillNetworkAssignmentTable()) { return handleError(); }

	return true;
}

function handleError() {
	global $objDatabase, $strQuery;

	return _databaseError($strQuery, $objDatabase->ErrorMsg());
}

function getActiveLanguages() {
	global $objDatabase;

	$arrReturn = array();

	$strQuery = '	SELECT		id
					FROM		'.DBPREFIX.'languages
					WHERE		frontend=1
					ORDER BY	id';

	$objResult = $objDatabase->Execute($strQuery);

	if ($objResult === false) {
		return $arrReturn;
	}

	while (!$objResult->EOF) {
		$arrReturn[count($arrReturn)] = $objResult->fields['id'];
		$objResult->MoveNext();
	}

	return $arrReturn;
}

function countRowsInTable($strTable) {
	global $objDatabase;
	$strQuery = "	SELECT	COUNT(*) as rows
					FROM `".$strTable."`";

	$objResult = $objDatabase->Execute($strQuery);

	if ($objResult === false) {
		return -1;
	} else {
		return intval($objResult->fields['rows']);
	}
}

function createSettingsTable() {
	global $objDatabase, $strQuery;

	$strQuery = "	CREATE TABLE IF NOT EXISTS `".DBPREFIX."module_blog_settings` (
  					`name`    VARCHAR(50)   NOT NULL,
 					`value`   VARCHAR(250)  NOT NULL,
  					PRIMARY KEY (`name`)
					) TYPE=".DB_ENGINE;

	$objResult = $objDatabase->Execute($strQuery);

	if ($objResult === false) {
		return false;
	}

	return true;
}

function fillSettingsTable() {
	global $objDatabase, $strQuery;

	switch (countRowsInTable(DBPREFIX."module_blog_settings")) {
		case -1:
			//Error while counting rows.
			return false;
			break;
		case 0:
			//No rows existing at the moment. Go on with filling tables.
		break;
		default:
			//Rows already have been inserted.
			return true;
	}

	$arrSettingsInserts = array(
		0	=>	"INSERT INTO `".DBPREFIX."module_blog_settings` (`name`,`value`) VALUES ('blog_general_introduction', '400');",
		1	=>	"INSERT INTO `".DBPREFIX."module_blog_settings` (`name`,`value`) VALUES ('blog_comments_editor', 'wysiwyg')",
		1	=>	"INSERT INTO `".DBPREFIX."module_blog_settings` (`name`,`value`) VALUES ('blog_comments_activated', '1');",
		2	=>	"INSERT INTO `".DBPREFIX."module_blog_settings` (`name`,`value`) VALUES ('blog_comments_anonymous', '0');",
		3	=>	"INSERT INTO `".DBPREFIX."module_blog_settings` (`name`,`value`) VALUES ('blog_comments_notification','1');",
		4	=>	"INSERT INTO `".DBPREFIX."module_blog_settings` (`name`,`value`) VALUES ('blog_comments_autoactivate','1');",
		5	=>	"INSERT INTO `".DBPREFIX."module_blog_settings` (`name`,`value`) VALUES ('blog_comments_timeout','30');",
		6	=>	"INSERT INTO `".DBPREFIX."module_blog_settings` (`name`,`value`) VALUES ('blog_voting_activated', '1');",
		7	=>	"INSERT INTO `".DBPREFIX."module_blog_settings` (`name`,`value`) VALUES ('blog_block_activated', '1');",
		8	=>	"INSERT INTO `".DBPREFIX."module_blog_settings` (`name`,`value`) VALUES ('blog_block_messages', '5');",
		9	=>	"INSERT INTO `".DBPREFIX."module_blog_settings` (`name`,`value`) VALUES ('blog_rss_activated', '1');",
		10	=>	"INSERT INTO `".DBPREFIX."module_blog_settings` (`name`,`value`) VALUES ('blog_rss_messages', '5');",
		11	=>	"INSERT INTO `".DBPREFIX."module_blog_settings` (`name`,`value`) VALUES ('blog_rss_comments', '20');",
		12	=>	"INSERT INTO `".DBPREFIX."module_blog_settings` (`name`,`value`) VALUES ('blog_tags_hitlist', '5');"
	);

	foreach ($arrSettingsInserts as $intKey => $strSettingQuery) {
		$strQuery = $strSettingQuery;
		$objResult = $objDatabase->Execute($strQuery);

		if ($objResult === false) {
			return false;
		}
	}


	return true;
}

function createEntryTable() {
	global $objDatabase, $strQuery;

	$strQuery = "	CREATE TABLE IF NOT EXISTS `".DBPREFIX."module_blog_messages` (
				  	`message_id`    INT(6)            UNSIGNED NOT NULL AUTO_INCREMENT,
				  	`user_id`       INT(5)            UNSIGNED NOT NULL,
				  	`time_created`  INT(14)           UNSIGNED NOT NULL DEFAULT '0',
				  	`time_edited`   INT(14)           UNSIGNED NOT NULL DEFAULT '0',
				  	`hits`          INT(7)            UNSIGNED NOT NULL DEFAULT '0',
				  	PRIMARY KEY (`message_id`)
					) TYPE=".DB_ENGINE;

	$objResult = $objDatabase->Execute($strQuery);

	if ($objResult === false) {
		return false;
	}

	return true;
}

function fillEntryTable() {
	global $objDatabase, $strQuery;

	switch (countRowsInTable(DBPREFIX."module_blog_messages")) {
		case -1:
			//Error while counting rows.
			return false;
			break;
		case 0:
			//No rows existing at the moment. Go on with filling tables.
		break;
		default:
			//Rows already have been inserted.
			return true;
	}

	$strQuery = "INSERT INTO `".DBPREFIX."module_blog_messages` (`user_id`,`time_created`) VALUES ('1',UNIX_TIMESTAMP());";
	$objResult = $objDatabase->Execute($strQuery);

	if ($objResult === false) {
		return false;
	}

	return true;
}

function createEntryTranslationTable() {
	global $objDatabase, $strQuery;

	$strQuery = "	CREATE TABLE IF NOT EXISTS `".DBPREFIX."module_blog_messages_lang` (
  					`message_id`    INT(6)          UNSIGNED NOT NULL,
  					`lang_id`       INT(2)          UNSIGNED NOT NULL,
  					`is_active`     ENUM('0','1')   NOT NULL DEFAULT '1',
  					`subject`       VARCHAR(250)    NOT NULL DEFAULT '',
  					`content`       TEXT            NOT NULL,
  					`tags`          VARCHAR(250)    NOT NULL DEFAULT '',
  					`image`         VARCHAR(250)    NOT NULL DEFAULT '',
  					PRIMARY KEY (`message_id`, `lang_id`),
  					FOREIGN KEY (`message_id`) REFERENCES `".DBPREFIX."module_blog_messages`(`message_id`) ON DELETE CASCADE
					) TYPE=".DB_ENGINE;

	$objResult = $objDatabase->Execute($strQuery);

	if ($objResult === false) {
		return false;
	}

	return true;
}

function fillEntryTranslationTable() {
	global $objDatabase, $strQuery;

	$arrLanguages = getActiveLanguages();
	if (count($arrLanguages) == 0) {
		return false;
	}

	switch (countRowsInTable(DBPREFIX."module_blog_messages_lang")) {
		case -1:
			//Error while counting rows.
			return false;
			break;
		case 0:
			//No rows existing at the moment. Go on with filling tables.
		break;
		default:
			//Rows already have been inserted.
			return true;
	}

	foreach ($arrLanguages as $intKey => $intLanguageId) {
		$strQuery = "INSERT INTO `".DBPREFIX."module_blog_messages_lang` (`message_id`,`lang_id`,`is_active`,`subject`,`content`,`tags`,`image`) VALUES ('1','".$intLanguageId."','1','New Contrexx Blog-Module!','This is a systemgenerated Blog-Message to demonstrate you our new module.','Contrexx, Blog, CMS','');";
		$objResult = $objDatabase->Execute($strQuery);

		if ($objResult === false) {
			return false;
		}
	}

	return true;
}

function createCategoryTable() {
	global $objDatabase, $strQuery;

	$strQuery = "	CREATE TABLE IF NOT EXISTS `".DBPREFIX."module_blog_categories` (
  					`category_id`   INT(4)            UNSIGNED NOT NULL,
  					`lang_id`       INT(2)            UNSIGNED NOT NULL,
  					`is_active`     ENUM('0','1')     NOT NULL DEFAULT '1',
 					`name`          VARCHAR(100)      NOT NULL DEFAULT '',
  					PRIMARY KEY (`category_id`, `lang_id`)
					) TYPE=".DB_ENGINE;

	$objResult = $objDatabase->Execute($strQuery);

	if ($objResult === false) {
		return false;
	}

	return true;
}

function fillCategoryTable() {
	global $objDatabase, $strQuery;

	$arrLanguages = getActiveLanguages();
	if (count($arrLanguages) == 0) {
		return false;
	}

	switch (countRowsInTable(DBPREFIX."module_blog_categories")) {
		case -1:
			//Error while counting rows.
			return false;
			break;
		case 0:
			//No rows existing at the moment. Go on with filling tables.
		break;
		default:
			//Rows already have been inserted.
			return true;
	}

	foreach ($arrLanguages as $intKey => $intLanguageId) {
		$strQuery = "INSERT INTO `".DBPREFIX."module_blog_categories` (`category_id`,`lang_id`,`is_active`,`name`) VALUES ('1','".$intLanguageId."','1','Blog');";
		$objResult = $objDatabase->Execute($strQuery);

		if ($objResult === false) {
			return false;
		}
	}

	return true;
}

function createCategoryAssignmentTable() {
	global $objDatabase, $strQuery;

	$strQuery = "	CREATE TABLE IF NOT EXISTS `".DBPREFIX."module_blog_message_to_category` (
  					`message_id`    INT(6)          UNSIGNED NOT NULL,
  					`category_id`   INT(4)          UNSIGNED NOT NULL,
  					`lang_id`       INT(2)          UNSIGNED NOT NULL,
  					PRIMARY KEY (`message_id`, `category_id`, `lang_id`),
					FOREIGN KEY (`message_id`) REFERENCES `".DBPREFIX."module_blog_messages`(`message_id`) ON DELETE CASCADE,
  					FOREIGN KEY (`category_id`) REFERENCES `".DBPREFIX."module_blog_categories`(`category_id`) ON DELETE CASCADE
					) TYPE=".DB_ENGINE;

	$objResult = $objDatabase->Execute($strQuery);

	if ($objResult === false) {
		return false;
	}

	return true;
}

function fillCategoryAssignmentTable() {
	global $objDatabase, $strQuery;

	$arrLanguages = getActiveLanguages();
	if (count($arrLanguages) == 0) {
		return false;
	}

	switch (countRowsInTable(DBPREFIX."module_blog_message_to_category")) {
		case -1:
			//Error while counting rows.
			return false;
			break;
		case 0:
			//No rows existing at the moment. Go on with filling tables.
		break;
		default:
			//Rows already have been inserted.
			return true;
	}

	foreach ($arrLanguages as $intKey => $intLanguageId) {
		$strQuery = "INSERT INTO `".DBPREFIX."module_blog_message_to_category` (`message_id`,`category_id`,`lang_id`) VALUES ('1','1','".$intLanguageId."');";
		$objResult = $objDatabase->Execute($strQuery);

		if ($objResult === false) {
			return false;
		}
	}

	return true;
}

function createVotingTable() {
	global $objDatabase, $strQuery;

	$strQuery = "	CREATE TABLE IF NOT EXISTS `".DBPREFIX."module_blog_votes` (
  					`vote_id`       INT(8)                      						UNSIGNED NOT NULL AUTO_INCREMENT,
  					`message_id`    INT(6)                      						UNSIGNED NOT NULL,
  					`time_voted`    INT(14)                     						UNSIGNED NOT NULL DEFAULT '0',
  					`ip_address`    VARCHAR(15)                							NOT NULL DEFAULT '0.0.0.0',
  					`vote`          ENUM('1','2','3','4','5','6','7','8','9','10')   	NOT NULL DEFAULT '1',
  					PRIMARY KEY (`vote_id`),
  					FOREIGN KEY (`message_id`) REFERENCES `".DBPREFIX."module_blog_messages`(`message_id`) ON DELETE CASCADE
					) TYPE=".DB_ENGINE;

	$objResult = $objDatabase->Execute($strQuery);

	if ($objResult === false) {
		return false;
	}

	return true;
}

function fillVotingTable() {
	global $objDatabase, $strQuery;

	switch (countRowsInTable(DBPREFIX."module_blog_votes")) {
		case -1:
			//Error while counting rows.
			return false;
			break;
		case 0:
			//No rows existing at the moment. Go on with filling tables.
		break;
		default:
			//Rows already have been inserted.
			return true;
	}

	$strQuery = "INSERT INTO `".DBPREFIX."module_blog_votes` (`message_id`,`time_voted`,`ip_address`,`vote`) VALUES ('1', UNIX_TIMESTAMP(), '127.0.0.1', '10');";
	$objResult = $objDatabase->Execute($strQuery);

	if ($objResult === false) {
		return false;
	}

	return true;
}

function createCommentTable() {
	global $objDatabase, $strQuery;

	$strQuery = "	CREATE TABLE IF NOT EXISTS `".DBPREFIX."module_blog_comments` (
  					`comment_id`    INT(7)          UNSIGNED NOT NULL AUTO_INCREMENT,
					`message_id`    INT(6)          UNSIGNED NOT NULL,
					`lang_id`       INT(2)          UNSIGNED NOT NULL,
					`is_active`     ENUM('0','1')   NOT NULL DEFAULT '1',
					`time_created`  INT(14)         UNSIGNED NOT NULL DEFAULT '0',
					`ip_address`    VARCHAR(15)     NOT NULL DEFAULT '0.0.0.0',
					`user_id`       INT(5)          UNSIGNED NOT NULL DEFAULT '0',
					`user_name`     VARCHAR(50)     NULL,
					`user_mail`     VARCHAR(250)    NULL,
					`user_www`      VARCHAR(255)    NULL,
					`subject`       VARCHAR(250)    NOT NULL DEFAULT '',
					`comment`       TEXT            NOT NULL,
  					PRIMARY KEY (`comment_id`),
  					FOREIGN KEY (`message_id`) REFERENCES `".DBPREFIX."module_blog_messages`(`message_id`) ON DELETE CASCADE
					) TYPE=".DB_ENGINE;

	$objResult = $objDatabase->Execute($strQuery);

	if ($objResult === false) {
		return false;
	}

	return true;
}

function fillCommentTable() {
	global $objDatabase, $strQuery;

	$arrLanguages = getActiveLanguages();
	if (count($arrLanguages) == 0) {
		return false;
	}

	switch (countRowsInTable(DBPREFIX."module_blog_comments")) {
		case -1:
			//Error while counting rows.
			return false;
			break;
		case 0:
			//No rows existing at the moment. Go on with filling tables.
		break;
		default:
			//Rows already have been inserted.
			return true;
	}

	foreach ($arrLanguages as $intKey => $intLanguageId) {
		$strQuery = "INSERT INTO `".DBPREFIX."module_blog_comments` (`message_id`,`lang_id`,`is_active`,`time_created`,`ip_address`,`user_id`,`user_name`,`user_mail`,`user_www`,`subject`,`comment`) VALUES ('1','".$intLanguageId."','1',UNIX_TIMESTAMP(),'127.0.0.1','0','Contrex CMS','info@contrexx.com','http://www.contrexx.com','First Comment in your Module','This is the first comment in your new blog module. We really hope you enjoy our new module.');";
		$objResult = $objDatabase->Execute($strQuery);

		if ($objResult === false) {
			return false;
		}
	}

	return true;
}

function createNetworkTable() {
	global $objDatabase, $strQuery;

	$strQuery = "	CREATE TABLE IF NOT EXISTS `".DBPREFIX."module_blog_networks` (
					`network_id`	INT(8)			UNSIGNED NOT NULL AUTO_INCREMENT,
					`name`			VARCHAR(250)    NOT NULL DEFAULT '',
					`url`    		VARCHAR(255)    NOT NULL DEFAULT '',
					`url_link`    	VARCHAR(255)    NOT NULL DEFAULT '',
					`icon`    		VARCHAR(255)    NOT NULL DEFAULT '',
					PRIMARY KEY (`network_id`)
					) TYPE=".DB_ENGINE;

	$objResult = $objDatabase->Execute($strQuery);

	if ($objResult === false) {
		return false;
	}

	return true;
}

function fillNetworkTable() {
	global $objDatabase, $strQuery;

	switch (countRowsInTable(DBPREFIX."module_blog_networks")) {
		case -1:
			//Error while counting rows.
			return false;
			break;
		case 0:
			//No rows existing at the moment. Go on with filling tables.
		break;
		default:
			//Rows already have been inserted.
			return true;
	}

	$arrNetworks = array(
		0	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (1, 'Digg', 'http://www.digg.com', 'http://digg.com/submit?phase=2&url=[URL]&title=[SUBJECT]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."digg.gif');",
		1	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (2, 'del.icio.ous', 'http://del.icio.us', 'http://del.icio.us/post?url=[URL]&title=[SUBJECT]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."delicious.gif');",
		2	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (3, 'Mister Wong', 'http://www.mister-wong.de', 'http://www.mister-wong.de/index.php?action=addurl&bm_url=[URL]&bm_description=[SUBJECT]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."wong.gif');",
		3	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (4, 'Google Bookmarks', 'http://www.google.com/bookmarks/', 'http://www.google.com/bookmarks/mark?op=edit&output=popup&bkmk=[URL]&title=[SUBJECT]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."google.gif');",
		4	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (5, 'Furl', 'http://www.furl.net', 'http://furl.net/storeIt.jsp?t=[SUBJECT]&u=[URL]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."furl.gif');",
		5	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (6, 'reddit', 'http://www.reddit.com/', 'http://reddit.com/submit?url=[URL]&title=[SUBJECT]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."reddit.gif');",
		6	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (7, 'Yigg', 'http://www.yigg.de', 'http://yigg.de/neu?exturl=[URL]&exttitle=[SUBJECT]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."yigg.gif');",
		7	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (8, 'BlinkList', 'http://www.blinklist.com', 'http://www.blinklist.com/index.php?Action=Blink/addblink.php&Description=&Url=[URL]&Title=[SUBJECT]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."blinklist.gif');",
		8	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (9, 'Blogmarks', 'http://www.blogmarks.net', 'http://blogmarks.net/my/new.php?mini=1&simple=1&url=[URL]&title=[SUBJECT]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."blogmarks.gif');",
		9	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (10, 'Co.mments', 'http://co.mments.com', 'http://co.mments.com/track?url=[URL]&title=[SUBJECT]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."comments.gif');",
		10	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (11, 'Feed Me Links', 'http://www.feedmelinks.com', 'http://feedmelinks.com/categorize?from=toolbar&op=submit&name=[SUBJECT]&url=[URL]&version=0.7', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."feedmelinks.gif');",
		11	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (12, 'Folkd', 'http://www.folkd.com', 'http://www.folkd.com/submit/page/[URL]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."folkd.gif');",
		12	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (13, 'Linkarena', 'http://www.linkarena.com', 'http://linkarena.com/bookmarks/addlink/?url=[URL]&title=[SUBJECT]&desc=&tags=', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."linkarena.gif');",
		13	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (14, 'Ma.gnolia', 'http://Ma.gnolia', 'http://ma.gnolia.com/bookmarklet/add?url=[URL]&title=[SUBJECT]&description=[SUBJECT]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."magnolia.gif');",
		14	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (15, 'Newsvine', 'http://www.newsvine.com', 'http://www.newsvine.com/_wine/save?u=[URL]&h=[SUBJECT]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."newsvine.gif');",
		15	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (16, 'OneView', 'http://beta.oneview.de', 'http://beta.oneview.de/quickadd/neu/addBookmark.jsf?URL=[URL]&title=[SUBJECT]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."oneview.gif');",
		16	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (17, 'RawSugar', 'http://www.rawsugar.com', 'http://www.rawsugar.com/tagger/?turl=[URL]&tttl=[SUBJECT]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."rawsugar.gif');",
		17	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (18, 'Squidoo', 'http://www.squidoo.com', 'http://www.squidoo.com/lensmaster/bookmark?[URL]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."squidoo.gif');",
		18	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (19, 'Stumble Upon', 'http://www.stumbleupon.com', 'http://www.stumbleupon.com/refer.php?url=[URL]&title=[SUBJECT]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."stumbleupon.gif');",
		19	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (20, 'Technorati', 'http://www.technorati.com', 'http://www.technorati.com/faves?add=[URL]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."technorati.gif');",
		20	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (21, 'Webnews', 'http://www.webnews.de', 'http://www.webnews.de/einstellen?url=[URL]&title=[SUBJECT]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."webnews.gif');",
		21	=>	"INSERT INTO `".DBPREFIX."module_blog_networks` (`network_id`, `name`, `url`, `url_link`, `icon`) VALUES (22, 'Yahoo My Web', 'http://myweb2.search.yahoo.com', 'http://myweb2.search.yahoo.com/myresults/bookmarklet?u=[URL]&t=[SUBJECT]', '".ASCMS_PATH_OFFSET."".NETWORK_IMAGE_PATH."yahoo.gif');"
	);

	foreach ($arrNetworks as $intKey => $strNetworkQuery) {
		$strQuery = $strNetworkQuery;
		$objResult = $objDatabase->Execute($strQuery);

		if ($objResult === false) {
			return false;
		}
	}

	return true;
}

function createNetworkAssignmentTable() {
	global $objDatabase, $strQuery;

	$strQuery = "	CREATE TABLE IF NOT EXISTS `".DBPREFIX."module_blog_networks_lang` (
					`network_id`		INT(8)			UNSIGNED NOT NULL,
					`lang_id`			INT(2)          UNSIGNED NOT NULL,
					PRIMARY KEY (`network_id`, `lang_id`),
					FOREIGN KEY (`network_id`) REFERENCES `".DBPREFIX."module_blog_networks`(`network_id`) ON DELETE CASCADE
					) TYPE=".DB_ENGINE;

	$objResult = $objDatabase->Execute($strQuery);

	if ($objResult === false) {
		return false;
	}

	return true;
}

function fillNetworkAssignmentTable() {
	global $objDatabase, $strQuery;

	$arrLanguages = getActiveLanguages();
	if (count($arrLanguages) == 0) {
		return false;
	}

	switch (countRowsInTable(DBPREFIX."module_blog_networks_lang")) {
		case -1:
			//Error while counting rows.
			return false;
			break;
		case 0:
			//No rows existing at the moment. Go on with filling tables.
		break;
		default:
			//Rows already have been inserted.
			return true;
	}

	foreach ($arrLanguages as $intKey => $intLanguageId) {
		for ($intNetworkId = 1; $intNetworkId <= 22; $intNetworkId++) {
			$strQuery = "INSERT INTO `".DBPREFIX."module_blog_networks_lang` (`network_id`, `lang_id`) VALUES (".$intNetworkId.", ".$intLanguageId.");";
			$objResult = $objDatabase->Execute($strQuery);

			if ($objResult === false) {
				return false;
			}
		}
	}

	return true;
}

?>